@@ -1,7 +1,4 @@
 # RDF::Trine
-# -------------
-# $Revision $
-# $Date $
 # -----------------------------------------------------------------------------
 
 
@@ -11,7 +8,7 @@ RDF::Trine - An RDF Framework for Perl.
 
 =head1 VERSION
 
-This document describes RDF::Trine version 0.105_02
+This document describes RDF::Trine version 0.107
 
 =head1 SYNOPSIS
 
@@ -33,8 +30,10 @@ use strict;
 use warnings;
 no warnings 'redefine';
 
+our ($debug, $VERSION);
 BEGIN {
-	our $VERSION	= '0.105_02';
+	$debug		= 0;
+	$VERSION	= '0.108_01';
 }
 
 use RDF::Trine::Parser;
@@ -54,7 +53,6 @@ __END__
 
 =head1 DEPENDENCIES
 
-L<Bloom::Filter>
 L<Data::UUID>
 L<DBI>
 L<DBD::SQLite>
@@ -70,7 +68,7 @@ L<Unicode::Escape>
 L<URI>
 L<XML::CommonNS>
 L<XML::Namespace>
-L<XML::Twig>
+L<XML::SAX>
 
 =head1 BUGS AND LIMITATIONS
 
