@@ -1,7 +1,4 @@
 # RDF::Trine::Node
-# -------------
-# $Revision: 121 $
-# $Date: 2006-02-06 23:07:43 -0500 (Mon, 06 Feb 2006) $
 # -----------------------------------------------------------------------------
 
 =head1 NAME
@@ -19,7 +16,15 @@ package RDF::Trine::Node;
 use strict;
 use warnings;
 no warnings 'redefine';
+
+our ($debug, $VERSION);
+BEGIN {
+	$debug		= 0;
+	$VERSION	= '0.107';
+}
+
 use Scalar::Util qw(blessed);
+use Unicode::String;
 
 use RDF::Trine::Node::Blank;
 use RDF::Trine::Node::Literal;
@@ -89,7 +94,7 @@ Returns the node in a string form.
 
 sub as_string {
 	my $self	= shift;
-	return $self->as_sparql;
+	return $self->sse;
 }
 
 =item C<< equal ( $node ) >>
@@ -102,6 +107,20 @@ sub equal {
 	return 0;
 }
 
+sub _unicode_escape {
+	# based on Unicode::Escape, but without running the string through Encode:: first.
+	my $self	= shift;
+	my $str		= shift;
+    my $us		= Unicode::String->new($str);
+    my $rslt = '';
+    while (my $uchar = $us->chop) {
+        my $utf8 = $uchar->utf8;
+        $rslt = (($utf8 =~ /[\x80-\xff]/) ? '\\u'.uc(unpack('H4', $uchar->utf16be)) : $utf8) . $rslt;
+    }
+    return $rslt;
+}
+
+
 1;
 
 __END__
