@@ -1,7 +1,4 @@
 # RDF::Trine::Node::Resource
-# -------------
-# $Revision: 121 $
-# $Date: 2006-02-06 23:07:43 -0500 (Mon, 06 Feb 2006) $
 # -----------------------------------------------------------------------------
 
 =head1 NAME
@@ -24,10 +21,10 @@ use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION, $debug, $lang, $languri);
+our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= do { my $REV = (qw$Revision: 121 $)[1]; sprintf("%0.3f", 1 + ($REV/1000)) };
+	$VERSION	= 0.107;
 }
 
 ######################################################################
@@ -64,7 +61,6 @@ sub new {
 		### the URI into an absolute URI, and then replace the breadcrumbs with
 		### the Unicode.
 		
-		
 		my $abs			= URI->new_abs( $uri, $base->uri_value );
 		$uri			= $abs->as_string;
 	}
@@ -127,30 +123,26 @@ sub sse {
 				return $qname;
 			}
 		}
-		my $string	= qq(<${uri}>);
+		
+		my $qname	= 0;
+		my $string	= qq(${uri});
 		foreach my $n (keys %$ns) {
 			if (substr($uri, 0, length($ns->{ $n })) eq $ns->{ $n }) {
 				$string	= join(':', $n, substr($uri, length($ns->{ $n })));
+				$qname	= 1;
 				last;
 			}
 		}
 		
-		return $string;
+		my $escaped	= $self->_unicode_escape( $string );
+		if ($qname) {
+			return $escaped;
+		} else {
+			return '<' . $escaped . '>';
+		}
 	}
 }
 
-=item C<< as_sparql >>
-
-Returns the SPARQL string for this node.
-
-=cut
-
-sub as_sparql {
-	my $self	= shift;
-	my $context	= shift;
-	return $self->sse( $context );
-}
-
 =item C<< as_string >>
 
 Returns a string representation of the node.
